﻿© Fluke Corporation. All Rights Reserved.                   MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub AT DSO8xxxx Compute Reference Gain
INSTRUMENT:            Sub AT DSO8xxxx Compute Max Freq Gain
DATE:                  2006-07-26
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       2
NUMBER OF LINES:       182
CONFIGURATION:         Agilent E4418B
CONFIGURATION:         Agilent E4413A on channel 1
CONFIGURATION:         Agilent E8257D
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Agilent DSO80204B, DSO80304B, DSO80404B, DSO80604B, DSO80804A/B,
#        DSO81004A/B, DSO81204A/B, DSO81304A/B
#
#  Compatibility:
#        MET/CAL 7.11 SP1 (7.11j) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  MATH         L[10] = GET("Chan")
  1.002  JMPL         REFERENCE_GAIN               PSUBI("Reference")
  1.003  JMPL         MAX_FREQ_GAIN                PSUBI("Max Freq")
  1.004  DISP         {Subprocedure not found}!
  1.005  END

  1.006  LABEL        REFERENCE_GAIN

# This sub calculates the 50 MHz gain (reference) during bandwidth testing.

  1.007  IF           M[1] < 1
  1.008  MATH         L[1] = M[1] / 1E-3
  1.009  HEAD         ANALOG BANDWIDTH (CH [L10]): [L1] mV/div, 50 MHz
  1.010  ELSE
  1.011  MATH         L[1] = M[1]
  1.012  HEAD         ANALOG BANDWIDTH (CH [L10]): [L1] V/div, 50 MHz
  1.013  ENDIF

  1.014  WAIT         -t 2 System settling...
# Get UUT reading (Vout @ 50 MHz).
  1.015  SCPI         MEAS:VRMS? DISP,AC,CHAN[L10][I]
# Copy UUT reading (Vout @ 50 MHz) to L[2].
  1.016  MATH         L[2] = MEM
# Get power meter reading (Vin @ 50 MHz).
  1.017  M4418  F64   E4413A
  1.018  4418         0.000001W                    50MH              RF N  CH1
# Convert power meter reading to Vrms (Vin @ 50 MHz) for use at MaxFreq.
  1.019  MATH         M[2] = SQRT(MEM * 50)
# Compute 50 MHz gain, saving to M[3] for subsequent use at Max Freq.
  1.020  MATH         M[3] = L[2] / M[2]

  1.021  END

  1.022  EVAL   Increment Test Number

  2.001  LABEL        MAX_FREQ_GAIN

# This sub is used to set the Signal Generator for the same output level as
# was previously used at the reference frequency, followed by computing the
# gain at the UUT Max Frequency.

# Global Variable Use:
#  M[1] - UUT time/div setting
#  M[2] - SigGen output setting at reference frequency
#  M[3] - UUT gain at 50 MHz (reference)
#
# Local Variable Use:
#  L[1] - SigGen lower output limit
#  L[2] - SigGen upper output limit
#  L[3] - SigGen output frequency (in GHz)
#  L[4] - UUT Volt/Div setting
#  L[5] - SigGen amplitude setting
#  L[6] - (Vin @ Max Freq)
#
#  Example:
# 1.001  MATH         M[1] = 5E-3
# 1.002  CALL         Sub AT DSO8xxxx Set Bandwidth Limit Output

# Compute lower limit for reference reading (nominal - 0.25%).
  2.002  MATH         L[1] = M[2] - (M[2] * 0.0025)
# Compute upper limit for reference reading (nominal + 0.25%).
  2.003  MATH         L[2] = M[2] + (M[2] * 0.0025)

  2.004  IF           GET("Bandwidth") == 2E+9
  2.005  SCPI         [@E8257]FREQ:CW 2E+9
  2.006  MATH         L[3] = 2
  2.007  ELSEIF       GET("Bandwidth") == 3E+9
  2.008  SCPI         [@E8257]FREQ:CW 3E+9
  2.009  MATH         L[3] = 3
  2.010  ELSEIF       GET("Bandwidth") == 4E+9
  2.011  SCPI         [@E8257]FREQ:CW 4E+9
  2.012  MATH         L[3] = 4
  2.013  ELSEIF       GET("Bandwidth") == 6E+9
  2.014  SCPI         [@E8257]FREQ:CW 6E+9
  2.015  MATH         L[3] = 6
  2.016  ELSEIF       GET("Bandwidth") == 8E+9
  2.017  SCPI         [@E8257]FREQ:CW 8E+9
  2.018  MATH         L[3] = 8
  2.019  ELSEIF       GET("Bandwidth") == 10E+9
  2.020  SCPI         [@E8257]FREQ:CW 10E+9
  2.021  MATH         L[3] = 10
  2.022  ELSEIF       GET("Bandwidth") == 12E+9

  2.023  IF           M[1] <= 5E-3
# Bandwidth on 5mV/div scale is 11.8 GHz!
  2.024  SCPI         [@E8257]FREQ:CW 11.8E+9
  2.025  MATH         L[3] = 11.8
  2.026  ELSE
  2.027  SCPI         [@E8257]FREQ:CW 12E+9
  2.028  MATH         L[3] = 12
  2.029  ENDIF

  2.030  ELSE
  2.031  DISP         Error: Unspecified Bandwidth!
  2.032  END
  2.033  ENDIF

  2.034  IF           M[1] < 1
  2.035  MATH         L[4] = M[1] / 1E-3
  2.036  HEAD         ANALOG BANDWIDTH (CH [L10]): [L4] mV/div, [L3] GHz
  2.037  ELSE
  2.038  MATH         L[4] = M[1]
  2.039  HEAD         ANALOG BANDWIDTH (CH [L10]): [L4] V/div, [L3] GHz
  2.040  ENDIF

# Nominal Vrms value for setting SigGen output value for desired vertical
# deflection, multiplied by 2 due to loss (6 dB) through power splitter.
  2.041  MATH         L[5] = M[2] * 2

# Set output of the SigGen so value is ±0.25% of reference value.
  2.042  DO
  2.043  SCPI         [@E8257]POW [L5]V
# Wait for SigGen output to settle prior to measuring level.
  2.044  WAIT         [D1000]
# Copy measurement frequency (in L[3]) to MEM for use in 4418 FSC.
  2.045  MATH         MEM = L[3]
  2.046  4418         0.000001W                    GH                RF N  CH1
# Convert power meter reading to Vrms, then multiply by 2 due to loss (6 dB)
# through power splitter for setting SigGen output value.
  2.047  MATH         MEM = (SQRT(MEM * 50)) * 2
# Compute required SigGen output to match level at reference frequency.
  2.048  MATH         L[5] = (M[2] * 2) + (L[5] - MEM)

# Trap to prevent excessive SigGen output (> 6 div.) from damaging UUT.
  2.049  IF           L[5] > (M[2] * 12)
  2.050  SCPI         [@E8257]OUTP:STAT OFF
  2.051  DISP         Error: E8257D output level set to unsafe value!
  2.052  END
  2.053  ENDIF

  2.054  UNTIL        (MEM >= (L[1] * 2)) && (MEM <= (L[2] * 2))

# Copy power meter reading (Vin @ Max Freq) to L[6].
  2.055  MATH         L[6] = MEM / 2
# Take reading from UUT (Vout @ Max Freq).
  2.056  SCPI         MEAS:VRMS? DISP,AC,CHAN[L10][I]
# Compute Max Freq gain.
  2.057  MATH         MEM = 20 * (LOG(MEM / L[6]) / M[3])

  2.058  END
